EncryptionOptions

Enum EncryptionOptions 

pub enum EncryptionOptions {
    None,
    AES_GCM {
        nonce: Vec<u8>,
    },
}
Options to be passed in while performing an encryption operation, if required by the algorithm.

Variants



None

No options are required. Most algorithms do not require additional parameters



AES_GCM

Options for AES GCM encryption.

Fields

nonce: Vec<u8>

Initialization vector, or nonce for the AES GCM encryption. MUST BE 96 bits long.

AES GCM encryption operations should not reuse the nonce, or initialization vector. Users should keep track of previously used nonces and not reuse them. A simple way to keep track is to simply increment the nonce as a 96 bit counter.

Implementations

Source

impl EncryptionOptions

pub fn description(&self) -> &'static str

Description of the type of key