pub struct Compact {
pub parts: Vec<Base64Url>,
}Expand description
A collection of CompactParts that have been converted to Base64Url
Fields
parts: Vec<Base64Url>Parts of the compact representation
Implementations
Sourceimpl Compact
impl Compact
Sourcepub fn with_capacity(capacity: usize) -> Compact
pub fn with_capacity(capacity: usize) -> Compact
Create an empty struct with some expected capacity
Sourcepub fn push(&mut self, part: &dyn CompactPart) -> Result<(), Error>
pub fn push(&mut self, part: &dyn CompactPart) -> Result<(), Error>
Push a CompactPart to the end
Sourcepub fn encode(&self) -> String
pub fn encode(&self) -> String
Encodes the various parts into Base64 URL encoding and then concatenates them with period ‘.’
This corresponds to the various Compact representation in JWE and JWS, for example